import { createRouter, createWebHistory } from 'vue-router'
import { ElMessage } from 'element-plus'
import Layout from '../layout/Layout.vue'
import { UserAPI } from '../api/user'

const routes = [
  {
    path: '/login',
    name: 'Login',
    component: () => import('../views/LoginView.vue')
  },
  {
    path: '/register',
    name: 'Register',
    component: () => import('../views/RegisterView.vue')
  },
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [
      {
        path: 'dashboard',
        name: 'Dashboard',
        component: () => import('../views/Dashboard.vue'),
        meta: { roles: ['admin', 'guest'] }
      },
      {
        path: 'tasks',
        name: 'Tasks',
        component: () => import('../views/TaskManagement.vue'),
        meta: { roles: ['admin'] }
      },
      {
        path: 'config',
        name: 'Config',
        component: () => import('../views/ConfigView.vue'),
        meta: { roles: ['admin'] }
      },
      {
        path: 'users',
        name: 'Users',
        component: () => import('../views/UserManagement.vue'),
        meta: { roles: ['admin'] }
      },
      {
        path: 'profile',
        name: 'Profile',
        component: () => import('../views/UserProfile.vue'),
        meta: { roles: ['admin', 'guest'] }
      },
      {
        path: 'events',
        name: 'Events',
        component: () => import('../views/UserEvents.vue'),
        meta: { roles: ['admin', 'guest'] }
      }
    ]
  },
  {
    path: '/:pathMatch(.*)*',
    redirect: '/dashboard'
  }
]

const router = createRouter({
  history: createWebHistory(),
  routes
})

// 简化路由守卫
router.beforeEach(async (to, from, next) => {
  const token = localStorage.getItem('token')
  const isAuthenticated = localStorage.getItem('isAuthenticated')
  const userRole = localStorage.getItem('userRole')
  
  // 登录页和注册页可以直接访问
  if (to.path === '/login' || to.path === '/register') {
    if (isAuthenticated) {
      next('/dashboard')
    } else {
      next()
    }
    return
  }

  if (!isAuthenticated) {
    next('/login')
    return
  }

  // 如果是管理员但没有用户信息，尝试获取
  if (userRole === 'admin' && token) {
    try {
      const response = await UserAPI.getUserInfo()
      if (response.retcode !== 0) {
        // 用户信息获取失败，清除登录状态
        localStorage.clear()
        next('/login')
        return
      }
    } catch (error) {
      localStorage.clear()
      next('/login')
      return
    }
  }

  // 检查权限
  if (to.meta.roles && !to.meta.roles.includes(userRole)) {
    ElMessage.error('没有访问权限')
    next('/dashboard')
    return
  }

  next()
})

export default router 